cubicweb.facets.js — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- Javascript »
- <no title> »

# cubicweb.facets.js

filter form, aka facets, javascript functions

> organization: | Logilab
> copyright: | 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
> contact: | http://www.logilab.fr/ – mailto:contact@logilab.fr

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- Javascript »
- <no title> »